@@ -31,9 +31,13 @@ class SALICONDataset(Dataset):
                 index:
         """
         img = self.__cvimg__(self.data[index])
-        if self.transform:
-            img = self.transform(img)
         target = cv2.imread((self.data[index].replace('/images/', '/maps/').replace('.jpg', '.png')), 0)
+
+        # for albumentations only!
+        if self.transform:
+            output = self.transform(image=img, saliency=target)
+            img = output['image']
+            target = output['saliency']
         target = target/target.sum()
         return img, target
 
